Rename certificates.{cc,h} -> certificate.{cc,h}.
[libdcp.git] / src / dcp.h
index effadfa3ebeb2b8f3538122359028b5415d572dc..44fe7621ed38e6b95041528d665c6818f7ae64d2 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -25,7 +25,7 @@
 #define LIBDCP_DCP_H
 
 #include "types.h"
-#include "certificates.h"
+#include "certificate.h"
 #include "metadata.h"
 #include <boost/shared_ptr.hpp>
 #include <boost/signals2.hpp>
@@ -41,7 +41,7 @@ namespace xmlpp {
 namespace dcp
 {
 
-class Content; 
+class Content;
 class Reel;
 class CPL;
 class XMLMetadata;
@@ -50,14 +50,10 @@ class DecryptedKDM;
 class Asset;
 class DCPReadError;
 
-namespace parse {
-       class AssetMap;
-}
-
 /** @class DCP
  *  @brief A class to create or read a DCP.
  */
-       
+
 class DCP : public boost::noncopyable
 {
 public:
@@ -71,7 +67,7 @@ public:
        DCP (boost::filesystem::path directory);
 
        typedef std::list<boost::shared_ptr<DCPReadError> > ReadErrors;
-       
+
        /** Read the DCP's structure into this object.
         *  @param keep_going true to try to keep going in the face of (some) errors.
         *  @param errors List of errors that will be added to if keep_going is true.
@@ -86,14 +82,10 @@ public:
         */
        bool equals (DCP const & other, EqualityOptions options, NoteHandler note) const;
 
-       void add (boost::shared_ptr<Asset> asset);
+       void add (boost::shared_ptr<CPL> cpl);
 
        std::list<boost::shared_ptr<CPL> > cpls () const;
-
-       /** @return All this DCP's assets (note that CPLs are assets) */
-       std::list<boost::shared_ptr<Asset> > assets () const {
-               return _assets;
-       }
+       std::list<boost::shared_ptr<Asset> > assets () const;
 
        bool encrypted () const;
 
@@ -116,7 +108,7 @@ private:
                XMLMetadata metadata,
                boost::shared_ptr<const Signer> signer
                ) const;
-       
+
        void write_volindex (Standard standard) const;
 
        /** Write the ASSETMAP file.
@@ -127,8 +119,8 @@ private:
 
        /** the directory that we are writing to */
        boost::filesystem::path _directory;
-       /** the assets that make up this DCP */
-       std::list<boost::shared_ptr<Asset> > _assets;
+       /** the CPLs that make up this DCP */
+       std::list<boost::shared_ptr<CPL> > _cpls;
 };
 
 }